==> seedsui-react-5.8.81.tgz: package/lib/Location/Modal/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["visible", "submitProps", "value", "type", "config", "getLocation", "getAddress"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { forwardRef } from 'react';
import Main from "./../Main";
import Footer from "./Footer";

// 内库使用
import locale from "./../../locale";
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { locale, Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// Modal
var LocationModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    submitProps = _ref.submitProps,
    value = _ref.value,
    type = _ref.type,
    config = _ref.config,
    getLocation = _ref.getLocation,
    getAddress = _ref.getAddress,
    props = _objectWithoutProperties(_ref, _excluded);
  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  if (type) props.MainProps.type = type;
  if (config) props.MainProps.config = config;
  if (getLocation) props.MainProps.getLocation = getLocation;
  if (getAddress) props.MainProps.getAddress = getAddress;

  // 底部
  props.MainProps.footerRender = function () {
    return visible === 'choose' ? /*#__PURE__*/React.createElement(Footer, {
      onOk: function onOk() {
        var _ref$current, _ref$current$submit;
        (_ref$current = ref.current) === null || _ref$current === void 0 || (_ref$current$submit = _ref$current.submit) === null || _ref$current$submit === void 0 || _ref$current$submit.call(_ref$current);
      },
      onClear: function onClear() {
        var _ref$current2, _ref$current2$submit;
        (_ref$current2 = ref.current) === null || _ref$current2 === void 0 || (_ref$current2$submit = _ref$current2.submit) === null || _ref$current2$submit === void 0 || _ref$current2$submit.call(_ref$current2, null);
      }
    }) : null;
  };
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: ref,
    captionProps: {
      caption: visible === 'choose' ? locale('选择地址', 'SeedsUI_choose_address') : locale('查看地址', 'SeedsUI_view_address')
    }
  }, props, {
    submitProps: _objectSpread({
      visible: visible === 'choose' ? true : false
    }, submitProps),
    visible: visible,
    value: value,
    className: "map-modal".concat(props.className ? ' ' + props.className : ''),
    MainComponent: Main
  }));
});
export default LocationModal;

==> seedsui-react-5.8.90.tgz: package/lib/Location/Modal/index.js <==
function _typeof(o) { "@babel/helpers - typeof"; return _typeof = "function" == typeof Symbol && "symbol" == typeof Symbol.iterator ? function (o) { return typeof o; } : function (o) { return o && "function" == typeof Symbol && o.constructor === Symbol && o !== Symbol.prototype ? "symbol" : typeof o; }, _typeof(o); }
var _excluded = ["visible", "submitProps", "value", "footerRender", "config", "getLocation", "getAddress"];
function _extends() { _extends = Object.assign ? Object.assign.bind() : function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }
function ownKeys(e, r) { var t = Object.keys(e); if (Object.getOwnPropertySymbols) { var o = Object.getOwnPropertySymbols(e); r && (o = o.filter(function (r) { return Object.getOwnPropertyDescriptor(e, r).enumerable; })), t.push.apply(t, o); } return t; }
function _objectSpread(e) { for (var r = 1; r < arguments.length; r++) { var t = null != arguments[r] ? arguments[r] : {}; r % 2 ? ownKeys(Object(t), !0).forEach(function (r) { _defineProperty(e, r, t[r]); }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) { Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r)); }); } return e; }
function _defineProperty(obj, key, value) { key = _toPropertyKey(key); if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }
function _toPropertyKey(t) { var i = _toPrimitive(t, "string"); return "symbol" == _typeof(i) ? i : String(i); }
function _toPrimitive(t, r) { if ("object" != _typeof(t) || !t) return t; var e = t[Symbol.toPrimitive]; if (void 0 !== e) { var i = e.call(t, r || "default"); if ("object" != _typeof(i)) return i; throw new TypeError("@@toPrimitive must return a primitive value."); } return ("string" === r ? String : Number)(t); }
function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }
function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }
import React, { useRef, forwardRef, useImperativeHandle } from 'react';
import Main from "./../Main";

// 内库使用
import locale from "./../../locale";
import ModalPicker from "./../../Modal/MainPicker";

// 测试使用
// import { locale, Modal } from 'seedsui-react'
// const ModalPicker = Modal.MainPicker

// Modal
var LocationModal = /*#__PURE__*/forwardRef(function (_ref, ref) {
  var visible = _ref.visible,
    submitProps = _ref.submitProps,
    value = _ref.value,
    footerRender = _ref.footerRender,
    config = _ref.config,
    getLocation = _ref.getLocation,
    getAddress = _ref.getAddress,
    props = _objectWithoutProperties(_ref, _excluded);
  var modalRef = useRef(null);
  useImperativeHandle(ref, function () {
    return modalRef.current;
  });

  // 扩展非标准属性
  if (!props.MainProps) {
    props.MainProps = {};
  }
  if (config) props.MainProps.config = config;
  if (getLocation) props.MainProps.getLocation = getLocation;
  if (getAddress) props.MainProps.getAddress = getAddress;
  return /*#__PURE__*/React.createElement(ModalPicker, _extends({
    ref: modalRef,
    captionProps: {
      caption: visible === 'choose' ? locale('选择地址', 'SeedsUI_choose_address') : locale('查看地址', 'SeedsUI_view_address')
    }
  }, props, {
    MainComponent: (props === null || props === void 0 ? void 0 : props.MainComponent) || Main,
    submitProps: _objectSpread({
      visible: visible === 'choose' ? true : false
    }, submitProps),
    visible: visible,
    value: value,
    className: "map-modal".concat(props.className ? ' ' + props.className : '')
  }));
});
export default LocationModal;
